LUTCubeLoader class

A 3D LUT loader that supports the .cube file format.

Based on the following reference: (https://wwwimages2.adobe.com/content/dam/acom/en/products/speedgrade/cc/pdfs/cube-lut-specification-1.0.pdf)

Inheritance

Constructors

LUTCubeLoader([LoadingManager? manager])
manager — The loadingManager for the loader to use. Default is DefaultLoadingManager.

Properties

crossOrigin ↔ String
getter/setter pairinherited
flipY ↔ bool
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
manager ↔ LoadingManager
getter/setter pairinherited
mimeType ↔ String
getter/setter pairinherited
path ↔ String
getter/setter pairinherited
requestHeader ↔ Map<String, dynamic>
getter/setter pairinherited
resourcePath ↔ String?
getter/setter pairinherited
responseType ↔ String
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
withCredentials ↔ bool
getter/setter pairinherited

Methods

dispose() → void
override
fromAsset(String asset, {String? package}) → Future<LUTCubeLoaderData?>
asset - path of the file to be loaded
override
fromBlob(Blob blob) → Future<LUTCubeLoaderData>
blob - a blob of the file to be loaded
override
fromBytes(Uint8List bytes) → Future<LUTCubeLoaderData>
bytes - the loaded bytes of the file
override
fromFile(File file) → Future<LUTCubeLoaderData>
file - the file to be loaded
override
fromNetwork(Uri uri) → Future<LUTCubeLoaderData?>
uri - a uri containing the location of the file to be loaded
override
fromPath(String filePath) → Future<LUTCubeLoaderData?>
filePath - path of the file to be loaded
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setCrossOrigin(String crossOrigin) → Loader
crossOrigin — The crossOrigin string to implement CORS for loading the url from a different domain that allows CORS.
inherited
setPath(String path) → Loader
path — Set the base path for the asset.
inherited
setRequestHeader(Map<String, dynamic> requestHeader) → Loader
requestHeader - key: The name of the header whose value is to be set. value: The value to set as the body of the header.
inherited
setResourcePath(String? resourcePath) → Loader
resourcePath — Set the base path for dependent resources like textures.
inherited
setWithCredentials(bool value) → Loader
Whether the XMLHttpRequest uses credentials such as cookies, authorization headers or TLS client certificates. See XMLHttpRequest.withCredentials.
inherited
toString() → String
A string representation of this object.
inherited
unknown(dynamic url) → Future
url - a dynmaic data that gets parsed by the system
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited