LUTCubeLoaderData class

Constructors

LUTCubeLoaderData({String? title, required num size, required Vector3 domainMax, required Vector3 domainMin, DataTexture? texture, Data3DTexture? texture3D})

Properties

domainMax ↔ Vector3
getter/setter pair
domainMin ↔ Vector3
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size ↔ num
getter/setter pair
texture ↔ DataTexture?
getter/setter pair
texture3D ↔ Data3DTexture?
getter/setter pair
title ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited